Page 87 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 87

Home

    Reserve that helped cause, and prolong, the Great
    Depression of 1929. It is often overlooked that the Great
    Depression of 1929 came sixteen years after the Federal
    Reserve was supposedly created to prevent just such an
    occurrence. The truth is, without the Federal Reserve, it

    would not have happened.
    Congressman Charles Lindbergh (father of the famous
    aviator Charles Lindberg) referred to the Federal Reserve

    as, "the invisible government by the money powers." He
    also stated, "This act establishes the most gigantic trust
    onearth. .. |!

    Congressman Louis McFadden, chairman of the
    House Committee on Banking and Currency from 1920

    When the Federal Reserve Act was passed, the
    people of these United States did not perceive that a
    world banking system was being set up here.

    A super-state controlled by international bankers and
    international industrialists acting together to enslave the
    world for their own pleasure.”

    This system, referred to by Congressman McFadden,
    is a privately owned banking system. Although its name,
    the Federal Reserve, implies that it is government owned

    and controlled, it is so powerful that not even Congress
    has ever been able to have it audited, nor does anyone
    outside its banking circles know who owns the bank.

    82

    The Secret Side of History

    was the action, and then the inaction, of the Federal

    on earth... .!

    to 1931, later declared: